package sysinfo

import (
	"encoding/json"
	"strings"
	"time"
)

type SystemCollector struct{}

func (SystemCollector) SectionKey() string { return "system" }

func (SystemCollector) EnsurePrerequisites(pm PackageManager, _ *Context) error {
	if pm.Distro() == "ubuntu" {
		return pm.InstallPackages("dmidecode")
	}
	return nil
}

func (SystemCollector) IsSupported(_ PackageManager, _ *Context) bool {
	return true
}

func (SystemCollector) CollectData(c *Context) (json.RawMessage, error) {
	data := map[string]string{
		"timestamp":   c.Now.Format(time.RFC3339),
		"distro":      "ubuntu",
		"uname":       c.SafeRun("uname", "-a"),
		"lsb_release": c.SafeRun("lsb_release", "-a"),
		"cpuinfo":     c.SafeRead("/proc/cpuinfo"),
		"meminfo":     c.SafeRead("/proc/meminfo"),
	}
	serial := strings.TrimSpace(
		c.SafeRun("dmidecode", "-s", "system-serial-number"))
	if serial != "" {
		data["id"] = serial
	}
	return json.Marshal(data)
}
